@@ -1,12 +1,11 @@
 import abc
+from typing import Optional
 
 from pydantic import BaseConfig, BaseModel, Field, validator  # noqa: F401
 
-from initcommerce.common.value_object import ID
-
 
 class BaseEntity(BaseModel, metaclass=abc.ABCMeta):
-    id: int = Field(default_factory=ID.fetch_one)
+    id: Optional[int]
 
     class Config(BaseConfig):
         orm_mode = True
