@@ -10,17 +10,23 @@ class InitCommerceBaseException(GraphQLError, metaclass=abc.ABCMeta):
     original_error = None
     message = "INIT_COMMERCE_BASE_EXCEPTION"
 
-    code: str = None
+    @property
+    def code(self) -> str:
+        class_name = self.__class__.__name__
+        return re.sub(r"(?<!^)(?=[A-Z])", "_", class_name).upper()
 
     def __init__(self, message=None, *args, **kwargs):
         super().__init__(message=message or self.message, *args, **kwargs)
 
-        if self.code is not None:
-            errorcode = self.code.replace(" ", "_").upper()
-        else:
-            class_name = self.__class__.__name__
-            errorcode = re.sub(r"(?<!^)(?=[A-Z])", "_", class_name).upper()
+        errorcode = self.code.replace(" ", "_").upper()
 
         self.extensions = dict(
             code=errorcode,
         )
+
+    def __repr__(self) -> str:
+        return self.extensions
+
+
+class InternalServerError(InitCommerceBaseException):
+    code = "INTERNAL_SERVER_ERROR"
