@@ -31,8 +31,8 @@ from initcommerce.common.uuid import UUID
 logger = get_logger("initcommerce-utils")
 
 
-def get_db(db_uri: str):
-    engine = _create_engine(db_uri, pool_pre_ping=True)
+def get_db(db_uri: str, isolation_level="READ COMMITTED") -> Session:
+    engine = _create_engine(db_uri, pool_pre_ping=True, isolation_level=isolation_level)
 
     SessionLocal = sessionmaker(
         autocommit=False,
